jsoncsv

package
v0.0.0-...-ce9e02a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 3, 2017 License: GPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func WalkWokring

func WalkWokring(outputDir, outputExt string, delimeter rune) filepath.WalkFunc

WalkWokring does the work recursively on a bunch of files.

func Work

func Work(input, output string, delimeter rune) (err error)

Work is a main wrapper function which controls the whole workflow.

Types

This section is empty.

Jump to